@@ -48,6 +48,7 @@
 ;; browse-url-iximosaic  IXI Mosaic  ?
 ;; browse-url-lynx-*	 Lynx	     0
 ;; browse-url-grail      Grail       0.3b1
+;; browse-url-kfm        kde
 
 ;; Note that versions of Netscape before 1.1b1 did not have remote
 ;; control.  <URL:http://www.netscape.com/newsref/std/x-remote.html>
@@ -384,6 +385,7 @@ Used by the `browse-url-at-point', `browse-url-at-mouse', and
 		(function-item browse-url-lynx-xterm)
 		(function-item browse-url-lynx-emacs)
 		(function-item browse-url-grail)
+		(function-item browse-url-kfm)
 		(function :tag "Other" nil))
   :group 'browse-url)
 
@@ -870,6 +872,15 @@ an Emacs buffer."
 	   (terminal-emulator "*browse-url*" "lynx" (list url)))
 	  (t (error "No terminal emulation in this XEmacs")))))
 
+;;;###autoload
+(defun browse-url-kfm (url &optional new-window)
+  ;; new-window ignored
+  "Ask the kfm WWW browser to load URL.
+Default to the URL around or before point."
+  (interactive (browse-url-interactive-arg "kfm URL: "))
+  (message "Sending URL to kfm...")
+    (start-process "kfmclient" nil "kfmclient" "openURL" url))
+
 (provide 'browse-url)
 
 ;;; browse-url.el ends here
