@@ -468,7 +468,8 @@ Possible values that work out of the box are:
 
 'w3-fetch                                == Use emacs-w3
 'highlight-headers-follow-url-netscape   == Use Netscape
-'highlight-headers-follow-url-mosaic     == Use Mosaic")
+'highlight-headers-follow-url-mosaic     == Use Mosaic
+'highlight-headers-follow-url-kfm        == Use kfm")
 
 (defvar highlight-headers-follow-url-netscape-auto-raise t
   "*Whether to make Netscape auto-raise when a URL is sent to it.")
@@ -499,6 +500,11 @@ Possible values that work out of the box are:
       (call-process "netscape" nil 0 nil url)))
   (message "Sending %s to Netscape... done" url))
 
+;;;###autoload
+(defun highlight-headers-follow-url-kfm (url)
+  (message "Sending %s to kfm..." url)
+  (start-process "kfmclient" nil "kfmclient" "openURL" url))
+
 ;;;###autoload
 (defun highlight-headers-follow-url-mosaic (url)
   (message "Sending URL to Mosaic...")
